@@ -25,6 +25,7 @@
 #include "pimcommon_debug.h"
 #include <QFile>
 #include <QJsonParseError>
+#include <QUrlQuery>
 
 using namespace PimCommon;
 
@@ -71,12 +72,14 @@ void HubicJob::requestTokenAccess()
     mError = false;
     mActionType = PimCommon::StorageServiceAbstract::RequestTokenAction;
     QUrl url(mServiceUrl + mAuthorizePath);
-    url.addQueryItem(QStringLiteral("response_type"), QStringLiteral("code"));
-    url.addQueryItem(QStringLiteral("client_id"), mClientId);
-    url.addQueryItem(QStringLiteral("redirect_uri"), mRedirectUri);
+    QUrlQuery query;
+    query.addQueryItem(QStringLiteral("response_type"), QStringLiteral("code"));
+    query.addQueryItem(QStringLiteral("client_id"), mClientId);
+    query.addQueryItem(QStringLiteral("redirect_uri"), mRedirectUri);
     if (!mScope.isEmpty()) {
-        url.addQueryItem(QStringLiteral("scope"), mScope);
+        query.addQueryItem(QStringLiteral("scope"), mScope);
     }
+    url.setQuery(query);
     mAuthUrl = url;
     //qCDebug(PIMCOMMON_LOG)<<" url"<<url;
     delete mAuthDialog;
@@ -103,7 +106,7 @@ void HubicJob::slotRedirect(const QUrl &url)
 
 void HubicJob::parseRedirectUrl(const QUrl &url)
 {
-    const QList<QPair<QString, QString> > listQuery = url.queryItems();
+    const QList<QPair<QString, QString> > listQuery = QUrlQuery(url).queryItems();
     //qCDebug(PIMCOMMON_LOG)<< "listQuery "<<listQuery;
 
     QString authorizeCode;
@@ -134,13 +137,13 @@ void HubicJob::getTokenAccess(const QString &authorizeCode)
     mError = false;
     QNetworkRequest request(QUrl(mServiceUrl + mPathToken));
     request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded"));
-    QUrl postData;
+    QUrlQuery postData;
     postData.addQueryItem(QStringLiteral("code"), authorizeCode);
     postData.addQueryItem(QStringLiteral("redirect_uri"), mRedirectUri);
     postData.addQueryItem(QStringLiteral("grant_type"), QStringLiteral("authorization_code"));
     postData.addQueryItem(QStringLiteral("client_id"), mClientId);
     postData.addQueryItem(QStringLiteral("client_secret"), mClientSecret);
-    QNetworkReply *reply = mNetworkAccessManager->post(request, postData.encodedQuery());
+    QNetworkReply *reply = mNetworkAccessManager->post(request, postData.query(QUrl::FullyEncoded).toUtf8());
     connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &HubicJob::slotError);
 }
 
@@ -293,14 +296,14 @@ void HubicJob::refreshToken()
     mActionType = PimCommon::StorageServiceAbstract::AccessTokenAction;
     QNetworkRequest request(QUrl(QStringLiteral("https://api.hubic.com/oauth/token/")));
     request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded"));
-    QUrl postData;
+    QUrlQuery postData;
     postData.addQueryItem(QStringLiteral("refresh_token"), mRefreshToken);
     postData.addQueryItem(QStringLiteral("grant_type"), QStringLiteral("refresh_token"));
     postData.addQueryItem(QStringLiteral("client_id"), mClientId);
     postData.addQueryItem(QStringLiteral("client_secret"), mClientSecret);
-    qCDebug(PIMCOMMON_LOG) << "refreshToken postData: " << postData;
+    qCDebug(PIMCOMMON_LOG) << "refreshToken postData: " << postData.queryItems();
 
-    QNetworkReply *reply = mNetworkAccessManager->post(request, postData.encodedQuery());
+    QNetworkReply *reply = mNetworkAccessManager->post(request, postData.query(QUrl::FullyEncoded).toUtf8());
     connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &HubicJob::slotError);
 }
 
